boto v2.19.0 — boto v2.25.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »

# boto v2.19.0

date: | 2013/11/27

This release adds support for max result limits for Amazon EC2 calls, adds support for Amazon RDS database snapshot copies and fixes links to the changelog.

## Features

- Add max results parameters to EC2 describe instances and describe tags.

    (issue 1873, issue 1873, commit ad8a64a)

- Add support for RDS CopyDBSnapshot. (issue 1872, issue 1872,

    issue 1865, commit bffb758)

## Bugfixes

- Update README.rst to link to ReadTheDocs changelogs. (issue 1869,

    commit 26f3dbe)

- Delete the old changelog in favor of the README link to ReadTheDocs

    changelogs. (issue 1870, issue 1870, commit 32bc333)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »